@@ -60,9 +60,6 @@
 #include <wpe/WebKitColor.h>
 #include <wpe/WebKitRectangle.h>
 #include <wpe/WebKitWebViewBackend.h>
-#if (defined(ENABLE_2022_GLIB_API) && ENABLE_2022_GLIB_API) && (defined(ENABLE_WPE_PLATFORM) && ENABLE_WPE_PLATFORM)
-#include <wpe/wpe-platform.h>
-#endif
 
 G_BEGIN_DECLS
 
@@ -151,8 +148,11 @@ typedef enum {
  * detected by trying to display any kind of resource (e.g. an image)
  * from an untrusted source.
  *
- * Enum values used to denote the different events which can trigger
- * the detection of insecure content.
+ * Enum values previously used to denote the different events which can trigger
+ * the detection of insecure content. Since 2.46, WebKit generally no longer
+ * loads insecure content in secure contexts.
+ *
+ * Deprecated: 2.46
  */
 typedef enum {
     WEBKIT_INSECURE_CONTENT_RUN,
@@ -336,13 +336,6 @@ webkit_web_view_new                                  (WebKitWebViewBackend
 WEBKIT_API WebKitWebViewBackend *
 webkit_web_view_get_backend                          (WebKitWebView             *web_view);
 
-#if (defined(ENABLE_2022_GLIB_API) && ENABLE_2022_GLIB_API) && (defined(ENABLE_WPE_PLATFORM) && ENABLE_WPE_PLATFORM)
-WEBKIT_API WPEDisplay *
-webkit_web_view_get_display                          (WebKitWebView             *web_view);
-
-WEBKIT_API WPEView *
-webkit_web_view_get_wpe_view                         (WebKitWebView             *web_view);
-#endif
 
 
 WEBKIT_API gboolean
